<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package GTS
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
set_time_limit(0);

add_action('admin_enqueue_scripts', 'include_media_button_js_file');
add_action('media_buttons', 'add_ink_import_btn');
add_filter('upload_mimes', 'allow_ink_file_to_upload_in_wp');
add_action( 'wp_ajax_ink_action', 'ink_action' );

include('parsedown.php');
include('metadata.php');
include('ink_settings.php');

/**
 * clean()
 *
 * @param mixed $string
 * @return
 */
function clean($string) {
    $string = preg_replace('/\s+/', '-', $string);
    $string = str_replace(array('"', '#', '$', '%', '&', "'", '(', ')', '*', '+', ',', '\\', '/', ':', ';', '<', '=', '>', '?', '@', '[', ']', '^', '_', '`', '{', '|', '}', '~'), '', $string);
    return $string;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * @since 1.0.0
 */
function ink_block_assets() {
    // Styles.
    wp_enqueue_style( 'ink-style-css', plugins_url( 'dist/blocks.style.build.css', dirname( __FILE__ ) ) );

    wp_enqueue_style('font-awesome', plugins_url( 'lib/css/fontawesome.min.css', dirname( __FILE__ ) ) );
    wp_enqueue_style('bootstrap-style', plugins_url( 'lib/css/bootstrap.min.css', dirname( __FILE__ ) ) );

    wp_enqueue_script('bootstrap-script',  plugins_url( 'lib/js/bootstrap.min.js', dirname( __FILE__ ) ), array('jquery'));
}

// Hook: Frontend assets. - no need -updated on 16th October 2019
//add_action( 'enqueue_block_assets', 'ink_block_assets' );
//add_action( 'wp_enqueue_scripts', 'ink_block_assets' );


/**
 * Registers an editor stylesheet for the theme.
 */
function wpdocs_theme_add_editor_styles() {
    add_editor_style( plugins_url( 'dist/blocks.editor.build.css', dirname( __FILE__ )) );
}
add_action( 'admin_init', 'wpdocs_theme_add_editor_styles' );

/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * `wp-blocks`: includes block type registration and related functions.
 * `wp-element`: includes the WordPress Element abstraction for describing the structure of your blocks.
 * `wp-i18n`: To internationalize the block's text.
 *
 * @since 1.0.0
 */
function ink_editor_assets() {
    // Scripts.
    wp_enqueue_script(
        'ink-block-js', // Handle.
        plugins_url( '/dist/blocks.buildnew.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
        array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
        true // Enqueue the script in the footer.
    );

    // Styles.
    wp_enqueue_style(
        'ink-block-editor-css', // Handle.
        plugins_url( 'dist/blocks.editor.build.css', dirname( __FILE__ ) ), // Block editor CSS.
        array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
    );
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'ink_editor_assets' );

function ink_add_block_category( $categories, $post ) {
    $categories[]=array(
        'slug'  => 'inkblock',
        'title' => 'INK Block',
    );
    return $categories;
}
add_filter( 'block_categories', 'ink_add_block_category', 10, 2);


add_filter( 'plugin_row_meta', 'ink_plugin_row_meta', 10, 2 );

function ink_plugin_row_meta( $actions, $plugin_file ) {

    if ( strpos( $plugin_file, 'ink-content-block.php' ) !== false ) {

        $action_links = array(
            'visitsite' => '<a href="https://seo.app/l0SIDLV3g" target="_blank">Visit Plugin Site</a>',
		    'visitseoblog' => 'Found a Bug? Email: <a href="mailto:support@inkco.co" target="_blank">support@inkco.co</a>'
        );

        $actions = array_merge( $actions, $action_links );
    }
    return $actions;
}

$pluginDirName = plugin_dir_url( __FILE__ );
$pluginDirName = preg_replace('/(src\/)?$/', '', $pluginDirName);
function add_ink_import_btn() {
    global $pluginDirName;
    echo '<a href="javascript:void(0)" id="ink_import_btn" class="button"><img src="'.$pluginDirName.'images/ink.png" />Import .ink File</a>';

    echo '<div id="inkloader" style="display:none"><img src="'.$pluginDirName.'images/progress.gif" /></div>';
}

function allow_ink_file_to_upload_in_wp( $existing_mimes=array() ) {
    $existing_mimes['ink'] = 'ink';
    return $existing_mimes;
}

function include_media_button_js_file() {
    global $pluginDirName;
    wp_enqueue_media();
    wp_enqueue_style('ink_css', $pluginDirName.'css/style.css');
    wp_register_script('ink_media_button', $pluginDirName.'js/ink_importer.js', array('jquery'), '1.6', true);
    wp_enqueue_script('ink_media_button');
    $pluginUrl = array( 'inkUrl' => admin_url( 'admin-ajax.php'), 'pluginsUrl' => plugins_url() );
    wp_localize_script( 'ink_media_button', 'inkObj', $pluginUrl );

}


function save_image( $base64_img,$alt,$cap,$title) {
    $alt = addslashes($alt);
    $cap = addslashes($cap);
//	$title = addslashes($title);
    $imgData=array();
    $rand=rand();
	$name = $title;
    $upload_dir = wp_upload_dir();
    $filename        = $name . '.jpg';
    $from_url = false;
	$extension = ".jpg";
    if(stristr($base64_img,'data:image/jpg;base64') !== FALSE || stristr($base64_img,'data:image/jpeg;base64')!== FALSE ){
        $filename        = $name . '.jpg';
		$extension = ".jpg";
    }else if(stristr($base64_img,'data:image/png;base64') !== FALSE){
        $filename        = $name . '.png';
		$extension = ".png";
    }else{
        $from_url = true;
        $i = $base64_img;
        $filename = basename($i);
        $ext = pathinfo($filename, PATHINFO_EXTENSION);
		$extension = "." . $ext;		
        if(!in_array($ext, 'png', 'jpg', 'jpeg'))
            $ext = 'png';
        $data = file_get_contents($i);
        $base64_img = 'data:image/'.$ext.';base64,' . base64_encode($data);
    }
    $img             = str_replace( 'data:image/jpg;base64', '', $base64_img );
    $img             = str_replace( 'data:image/jpeg;base64', '', $img );
    $img             = str_replace( 'data:image/png;base64', '', $img );
    $img             = str_replace( ' ', '+', $img );
    $decoded         = base64_decode( $img );
    if(!$from_url) {
        $filename = stripslashes($filename);
        $filename = clean($filename);
    }
	$file_directory = "";
    if( wp_mkdir_p( $upload_dir['path'] ) ) {
        $file = $upload_dir['path'] . '/' . $filename;
		$file_directory = $upload_dir['path'] . '/';
	}else{
        $file = $upload_dir['basedir'] . '/' . $filename;
		$file_directory = $upload_dir['basedir'] . '/';
    }
	$iLoop = 1;
	if(file_exists($file)) {$upload_file = file_put_contents($file . '.ink' , '' );$upload_file = file_put_contents($file . '.ink' , $decoded );
	if (filesize($file . '.ink') == filesize($file)) {} else {
		 $iLoop = 1;
		while(file_exists($file))
		{
			$file = $file_directory . $name."-".$iLoop++ . $extension;	
		}
		$upload_file = file_put_contents($file , $decoded );
		} } else {
    $upload_file = file_put_contents($file , $decoded );
		}
    $wp_filetype = wp_check_filetype( $filename, null );
    $attachment = array(
        'post_mime_type' => $wp_filetype['type'],
        'post_title'     => sanitize_file_name($filename),
        'post_content'   => "",
        'post_status'    => 'inherit',
        'post_excerpt'  => $cap,
    );
	
    $attach_id = wp_insert_attachment( $attachment,$file  );
    $attach_data = wp_generate_attachment_metadata($attach_id, $file);
    wp_update_attachment_metadata($attach_id, $attach_data);
    update_post_meta($attach_id, '_wp_attachment_image_alt', $alt);
    $imagePath=wp_get_attachment_metadata( $attach_id );
    $imgData['url'] = wp_get_attachment_url($attach_id);
    $imgData['path']=$imagePath;
    $imgData['id']=$attach_id;
    return $imgData;
}
function strposX($haystack, $needle, $n = 0){
    $offset = 0;
    for ($i = 0; $i < $n; $i++) {
        $pos = strpos($haystack, $needle, $offset);

        if ($pos !== false) {
            $offset = $pos + strlen($needle);
        } else {
            return false;
        }
    }

    return $offset;
}


function ink_action() {
	
		if (!isset($_POST['ink_file_url'])) {
        return;
    } else {
		$fileUrl = esc_url_raw($_POST['ink_file_url']);
	}

    try {
        $data=array();
        $images_data=array();
        $images = array();
		$filename = basename($fileUrl);
		$upload_dir = wp_upload_dir();
		
		
    if( wp_mkdir_p( $upload_dir['path'] ) ) {
        $fileUrl = $upload_dir['path'] . '/' . $filename;
	}else{
        $fileUrl = $upload_dir['basedir'] . '/' . $filename;
    }
		
   //     $fileUrl = substr($fileUrl, strpos($fileUrl, 'wp-content'));

        $fp = fopen($fileUrl, "r");
        
		if ( !$fp ) {

		}
        
		$content = fread($fp, filesize($fileUrl));
	//	$content = file_get_contents($fp);
//$content = "This is a test text" . $fileUrl;
        preg_match_all('/<img[^>]+>/i',$content, $imgTags);

        $images_Rep = array();
        $images_guten_Rep = array();
        if($imgTags){
            foreach ($imgTags[0] as $iKey => $image){
                $image_data = $image;
                $image_data_with = 'INK_IMG_'.$iKey.'_'.time();
                $content = str_replace($image, $image_data_with, $content);
                $images_Rep[$image_data_with][] = $image_data;
                $images_guten_Rep[$image_data_with][] = $image_data;

                preg_match('/src="([^"]+)/i',$image, $imgsrc);
                preg_match('/alt="([^"]+)/i',$image, $imgAlt);
                preg_match('/caption="([^"]+)/i',$image, $imgCap);
				preg_match('/title="([^"]+)/i',$image, $imgtitle);

                preg_match('/align="([^"]+)/i',$image, $imgAlign);
                preg_match('/width="([^"]+)/i',$image, $imgWidth);

                $src = str_ireplace( 'src="', '',  $imgsrc[0]);

                $alt = str_ireplace( 'alt="', '',  $imgAlt[0]);
                $alt = htmlspecialchars_decode($alt);


                $cap = str_ireplace( 'caption="', '',  $imgCap[0]);
                $cap = htmlspecialchars_decode($cap);
				
				$title = str_ireplace( 'title="', '',  $imgtitle[0]);
                $title = htmlspecialchars_decode($title);
				if($title=='')
                {
						$content_as=substr($alt,0,50);
	$lastoccur = strrpos($content_as," ");
	$content_as = substr($content_as,0,$lastoccur);
    $content_as=str_replace(" ", "-", $content_as);
	$content_as = preg_replace("/[^a-z0-9\_\-\.]/i", '', str_replace("--", "-", $content_as));
    $name = $content_as;
    $name = urldecode($name);
    $name=str_replace('.', '', $name);
    $name=str_replace('%', '', $name);
                    $title = $name;
                }


                $width = str_ireplace( 'width="', '',  $imgWidth[0]);
                $align = str_ireplace( 'align="', '',  $imgAlign[0]);

                $wpImgUrl = save_image($src,$alt,$cap,$title);
                $images[] = $wpImgUrl;
                $images_data[] = $wpImgUrl['id'];

                $cal_width = $width;
                $cal_height = 'auto';

				if (strpos($width, '%') !== false) {
                    $width_img = $wpImgUrl['path']['width'];
                    $height_img = $wpImgUrl['path']['height'];
                    $cal_width = ((int)$width / 100) * $width_img;
                    $cal_height = 'auto';
                    $cal_width = (int)$cal_width;
                }
				
                $editor_width = 610;
                $img_width = 610;
                
				if (strpos($width, '%') !== false) {
                    $img_width = ((int)$width / 100) * $editor_width;
                }

                if($cal_width < $img_width){
                    $img_width = $cal_width;
                }

                if($alt=='')
                {
                    $alt = ' ';
                }

				if($cap == ''){
                    $images_Rep[$image_data_with][] = '[caption id="attachment_'.$wpImgUrl['id'].'" align="align'.$align.'" width="'.(int)$img_width.'"]<img class="wp-image-'.$wpImgUrl['id'].' align'.$align.'" src="'.$wpImgUrl['url'].'" alt="'.$alt.'" width="'.(int)$img_width.'"/> '.$cap.' [/caption]';
                }else{
                    $images_Rep[$image_data_with][] = '[caption id="attachment_'.$wpImgUrl['id'].'" align="align'.$align.'" width="'.(int)$img_width.'"]<img class="wp-image-'.$wpImgUrl['id'].' '.$align.'" src="'.$wpImgUrl['url'].'" alt="'.$alt.'" width="'.(int)$img_width.'"/> '.$cap.'[/caption]';
                }


                $images_guten_Rep['INK_IMG_'.$iKey] = array(
                    'align' => $align,
                    'alt' => $alt,
                    'caption' => $cap,
                    'id' => $wpImgUrl['id'],
                    'url' => $wpImgUrl['url'],
                    'url' => $wpImgUrl['url'],
                    'height' => '',
                    'width' => (int)$img_width,
                    'original_width' => $width,
                );
            }
        }
        $Parsedown = new Parsedown();

        $meta_info=$Parsedown->text($content);

        ///////=============Meta Desc==============/////////
        $metaDesc = "";
        if(strpos($meta_info, "metadesc:")){
            $meta_desc = substr($meta_info, strpos($meta_info, "metadesc:") + 1);
            $meta_desc = explode('&quot;', $meta_desc);
            $metaDesc = urldecode($meta_desc[1]);
        }
        ///////=============Meta Title==============/////////
        $metaTitle = "";
        if(strpos($meta_info, "metatitle:")) {
            $meta_title = substr($meta_info, strpos($meta_info, "metatitle:") + 1);
            $meta_title = explode('&quot;', $meta_title);
            $metaTitle = urldecode($meta_title[1]);
        }

        ///////=============Keywords==============/////////
        $meta_keywords = "";
        if(strpos($meta_info, "keywords :")){
            $meta_keywords = substr($meta_info, strpos($meta_info, "keywords :") + 10);
        }else {
            $meta_keywords = substr($meta_info, strpos($meta_info, "keywords:") + 9);
        }
        $keyWordsEnd = strposX($meta_keywords, 'title', 1);
        $metakeywords = substr($meta_keywords,0,($keyWordsEnd-5));
        $metakeywords = strip_tags($metakeywords);
        $metakeywords = urldecode($metakeywords);
        $metakeywords = str_replace('&quot;','',$metakeywords);
        $metakeywords = str_replace("'",'',$metakeywords);
        $metakeywords = urldecode($metakeywords);
        $metakeywords = preg_replace("/(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+/", "\n", $metakeywords);
        $metakeywords = str_replace(array("\r\n","\r","\n"),', ',trim($metakeywords));

        $content = preg_replace('/outlinenotes: (\'|")[^\'"]+(\'|")/', 'outlinenotes: ""', $content);
        $content = preg_replace('/ignored: [^\s\n]+/', 'ignored: ', $content);

        $content=substr_replace($content, '', 0, strposX($content, '---', 2)+3);


        $htmlContent=$Parsedown->text($content);
        $strtTitle=strpos($htmlContent,"<h1>");
        $endTitle=strpos($htmlContent,"</h1>");
        $postTitle=substr($htmlContent,$strtTitle+4,$endTitle-4);
        $htmlContent=substr_replace($htmlContent, '', $strtTitle, $endTitle+5);

        if(strpos($htmlContent,"<img")<3){
            $imgStrt=strpos($htmlContent,"<img");
            $imgEnd=strpos($htmlContent,">");
            $imageTag=substr($htmlContent,$imgStrt,$imgEnd);
            preg_match('/src="([^"]+)/i',$htmlContent, $imgUrl);
            $thumbnail_url = str_ireplace( 'src="', '',  $imgUrl[0]);
            $thumbnail_id=$images_data[0];
            $htmlContent=substr_replace($htmlContent, '', $imgStrt, $imgEnd);
        }
        $inkYoutube=get_option('ink_yotube_settings');

        /*
         * Image Above 500 Code
         */
        $data['thumbnail_id'] = 0;
        if(count($images) > 0){
            foreach ($images as $rowImg){
                //list($width, $height) = getimagesize($rowImg['path']);

                $width = $rowImg['path']['width'];
                $height = $rowImg['path']['height'];
                if($width > 500){
                    $data['thumbnail_id'] = $rowImg['id'];
                    $data['thumbnail_url'] = $rowImg['url'];
                    break;
                }
            }
        }

        $htmlContent = '<p'.$htmlContent;
        $htmlContent = str_replace("<p></p>", "", $htmlContent);
        $htmlContent_guten = $htmlContent;
		if($inkYoutube){
        	$htmlContent = preg_replace("/\s*<a href=\"(https:\/\/)*[wW]*\.youtube\.com\/watch\?v=([a-zA-Z0-9\-_]+)(&amp;)*[A-Za-z=\.]*\">(https:\/\/)*[wW]*\.youtube\.com\/watch\?v=[a-zA-Z0-9\-_]+(&amp;)*[A-Za-z=\.]*<\/a>/i","<div class=\"ink_container\"><iframe  class=\"ink_video\" src=\"//www.youtube.com/embed/$2\" frameborder=\"0\" allowfullscreen></iframe></div>", $htmlContent);
	        $htmlContent = preg_replace("/\s*<a href=\"https:\/\/youtu\.be\/([a-zA-Z0-9\-_]+)\">[a-zA-Z]*:\/\/youtu\.be\/([a-zA-Z0-9\-_]+)<\/a>/i","<div class=\"ink_container\"><iframe class=\"ink_video\" src=\"//www.youtube.com/embed/$2\" frameborder=\"0\" allowfullscreen></iframe></div>", $htmlContent);
		
			$htmlContent_guten = preg_replace("/\s*<a href=\"(https:\/\/)*[wW]*\.youtube\.com\/watch\?v=([a-zA-Z0-9\-_]+)(&amp;)*[A-Za-z=\.]*\">(https:\/\/)*[wW]*\.youtube\.com\/watch\?v=[a-zA-Z0-9\-_]+(&amp;)*[A-Za-z=\.]*<\/a>/i","<div class=\"ink_container\">https://www.youtube.com/watch?v=$2</div>", $htmlContent_guten);
			$htmlContent_guten = preg_replace("/\s*<a href=\"https:\/\/youtu\.be\/([a-zA-Z0-9\-_]+)\">[a-zA-Z]*:\/\/youtu\.be\/([a-zA-Z0-9\-_]+)<\/a>/i","<div class=\"ink_container\">https://www.youtube.com/watch?v=$2</div>", $htmlContent_guten);
		
		}
        if($images_Rep){
            foreach($images_Rep as $iKey => $value){
                $htmlContent = str_replace($iKey, $value[1], $htmlContent);
            }
        }
$htmlContent_guten = str_replace("<h", "<replaceme><h", $htmlContent_guten);
$htmlContent_guten = str_replace("<p>", "<replaceme>", $htmlContent_guten);
$htmlContent_guten = str_replace(" <ul", "<ul", $htmlContent_guten);
$htmlContent_guten = str_replace("<ul", "<replaceme><ul", $htmlContent_guten);
$htmlContent_guten = str_replace(" <ol", "<ol", $htmlContent_guten);
$htmlContent_guten = str_replace("<ol", "<replaceme><ol", $htmlContent_guten);
$htmlContent_guten = str_replace("\n", '', $htmlContent_guten);
        $data['title'] = $postTitle;
        $data['content'] = $htmlContent;
        $data['guten_content'] = explode("<replaceme>", $htmlContent_guten);
        $data['guten_images'] = $images_guten_Rep;
        $data['images_Rep'] = $images_Rep;
        $data['ink_metadesc'] = trim($metaDesc);
        $data['ink_metatitle'] = trim($metaTitle);
        $data['ink_keywords'] = trim($metakeywords);

        /*
         * Yoast plugin
         */

        $data['yoast_wpseo_metadesc'] = trim($metaDesc);

        echo json_encode($data);

        wp_die();
    }
    catch(Exception $exception)
    {
        echo  $exception->getTraceAsString();
    }
}

/**
 * Check if Block Editor is active.
 * Must only be used after plugins_loaded action is fired.
 *
 * @return bool
 */

function is_gutenberg() {
	
    // Gutenberg plugin is installed and activated.
    $gutenberg = ! ( false === has_filter( 'replace_editor', 'gutenberg_init' ) );

    // Block editor since 5.0.
    $block_editor = version_compare( $GLOBALS['wp_version'], '5.0', '>' );

    if ( ! $gutenberg && ! $block_editor ) {
        return false;
    }

    if ( is_classic_editor_plugin_active() ) {
        $editor_option       = get_option( 'classic-editor-replace' );
        $block_editor_active = array( 'no-replace', 'block' );

        return in_array( $editor_option, $block_editor_active, true );
    }
    return true;
}

/**
 * Check if Classic Editor plugin is active.
 *
 * @return bool
 */
function is_classic_editor_plugin_active() {
    if ( ! function_exists( 'is_plugin_active' ) ) {
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
    }

    if ( is_plugin_active( 'classic-editor/classic-editor.php' ) ) {
        return true;
    }

    return false;
}

/* INK File Generation */
function ink_link($post_ID) {
	$link = '<div class="downloadinkbtn"><a class="downloadink" href="/wp-admin/admin-ajax.php?id=' . $post_ID . '&action=generate_ink"><img border="0" alt="Generate .ink" src="' . plugins_url("ink-official/images/ink_download.svg") . '" width="20" height="20"></a></div>';
    return $link;
}
function inkfiledownload_head($defaults) {
    $defaults['download_ink'] = '<div class="inktooltip">Download .ink file<div class="inkpointer"><span id="inktooltiptext" class="inktooltiptext" data="Generate and download an .ink file from this WordPress post so you can easily optimize it in inkforall.com"></span></div></div>';
    return $defaults;
}
function inkfiledownload_content($column_name, $post_ID) {
           if( 'download_ink' == $column_name ) {  
		   echo ink_link($post_ID);
		   }
}
add_filter('manage_posts_columns', 'inkfiledownload_head');
add_action('manage_posts_custom_column', 'inkfiledownload_content', 11, 2);

function generate_ink(){
$upload_dir = wp_upload_dir();
 $offset = $_GET['offset'];
 $id= $_GET['id'];
if (get_post_meta($id, 'ink_use_meta_data', true ) ){$keyword = get_post_meta( $id, 'ink_keywords', true );} else {$keyword = get_post_meta( $id, 'yoast_wpseo_focuskw', true );}
$authorid = get_post_field( 'post_author', $id);
$inkcontent = "";
$inkcontent .= "---";
$inkcontent .= "\nauthor : '" . get_the_author_meta('display_name', $authorid) . "'\n";
$inkcontent .= "app :\n - name: INK\n - articleId: '7644aae6-9606-d8d5-1463-43e82432e34c'\n - version: 1.193.0\n - metadesc: ''\n - metatitle: ''\n - outlinenotes: ''\n - kwData: \n - ignored: \n - kwLocation: \n";
$inkcontent .= "date :  " . date("Y/m/d H:i:s") . "\n";
$inkcontent .= "keywords :\n";
$inkcontent .= " - '" . $keyword . "'\n";
$inkcontent .= "title : |\n";
$inkcontent .= " '" . get_the_title($id) . "'\n";
$inkcontent .= "---\n";
$inkcontent .= "\n\n\n";
$inkcontent .= get_the_title($id) . "\n";
$inkcontent .= "=========================================================\n";
if ( has_post_thumbnail($id) ) {
	$turl = get_the_post_thumbnail_url($id);
	$b64fimg1 = base64_encode(file_get_contents($turl));
	$tcaption = get_the_post_thumbnail_caption($id);
	$fimg = '<img src="data:image/jpeg;base64,'. $b64fimg1 .'" align="none" width="" caption="" alt="'.$tcaption.'" />('. $turl .')';
$inkcontent .= $fimg;
}
	$content_post = get_post($id);
$content = $content_post->post_content;
$content = apply_filters('the_content', $content);
  if (preg_match_all('#<iframe(?:.*)?\ssrc=["|\']https:\/\/www\.youtube\.com\/embed\/(.*)["|\']\s(?:.*)><\/iframe>#Usm', $content, $matches, PREG_SET_ORDER)) {
	foreach ($matches as $match) {
	  $content = str_replace($match[0], 'https://youtu.be/'.$match[1], $content);
	}
  }
$inkcontent .= $content;
$filename = sanitize_title(get_the_title($id));
    if( wp_mkdir_p( $upload_dir['path'] ) ) {
        $file = $upload_dir['path'] . '/wp-' . $filename . '.ink';
	}else{
        $file = $upload_dir['basedir'] . '/wp-' . $filename . '.ink';
    }
$filew = fopen("$file", "w") or die("Unable to open file!");
	fwrite($filew,  $inkcontent. "\n");
fclose($filew);
	header('Content-Description: File Transfer');
header('Content-Disposition: attachment; filename='.basename($file));
header('Expires: 0');
header('Cache-Control: must-revalidate');
header('Pragma: public');
header('Content-Length: ' . filesize($file));
header("Content-Type: text/plain");
readfile($file);
	die();
 }

add_action('wp_ajax_generate_ink', 'generate_ink');
/* Ink File Generation End */